@@ -34,7 +34,8 @@ if (keep.annotations=="yes") {
 dat2<-normalizeBetweenArrays(dat$R, method="none")
 
 # Writes out a phenodata table
-sample<-paste(colnames(dat2), ".tsv", sep="")
+# sample<-paste(colnames(dat2), ".tsv", sep="")
+sample<-colnames(dat2)
 group<-c(rep("", length(sample)))
 training<-c(rep("", length(sample)))
 time<-c(rep("", length(sample)))
@@ -62,9 +63,10 @@ if (keep.annotations=="yes") {
 
 if(chiptype!="cDNA") {
 	# Including gene names to data
+	lib2<-sub('.db','',chiptype)
 	library(chiptype, character.only=T)
-	symbol<-gsub("\'", "", data.frame(unlist(as.list(get(paste(chiptype, "SYMBOL", sep="")))))[rownames(M2),])
-	genename<-gsub("\'", "", data.frame(unlist(as.list(get(paste(chiptype, "GENENAME", sep="")))))[rownames(M2),])
+	symbol<-gsub("\'", "", data.frame(unlist(as.list(get(paste(lib2, "SYMBOL", sep="")))))[rownames(M2),])
+	genename<-gsub("\'", "", data.frame(unlist(as.list(get(paste(lib2, "GENENAME", sep="")))))[rownames(M2),])
 	write.table(data.frame(symbol, description=genename, round(M2, digits=2)), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
 }
 
